
# Mash constants
MAX_MASH_DIST = '0.1'
UNFILTERED_MASH_DIST = '0.3'

# DNA fragmentation constants
FRAGMENT_SIZE = 1020
MIN_FRAGMENT_SIZE = 100

CITATION = '''Schwengers et al., (2020)
ReferenceSeeker: rapid determination of appropriate reference genomes.
Journal of Open Source Software, 5(46), 1994, https://doi.org/10.21105/joss.01994'''
